@@ -1,28 +1,25 @@
 """Logger implementation"""
 
-import os
 import logging
+import os
 import re
-import traceback
 import sys
-from logging import DEBUG, INFO, WARNING, ERROR, FATAL
-
+import traceback
 from datetime import datetime
-from elasticsearch import Elasticsearch
+from logging import DEBUG, ERROR, FATAL, INFO, WARNING
+from typing import Any, AnyStr, Dict, NoReturn, Optional
+
 from pythonjsonlogger import jsonlogger
 
-import certifi
-import sentry_sdk
-from sentry_sdk.integrations.logging import LoggingIntegration, ignore_logger
+import elasticlogger.elastic as elastic
 
 from .context import Context
-from .errors import ESEmptyIndexError, ESEmptyUrlError, ESConfigurationError, SentryEmptyUrlError, InvalidLogLevel
-from .json_encoder import LoggerJSONEncoder, ElasticJSONEncoder
+from .errors import (ESConfigurationError, ESEmptyIndexError, ESEmptyUrlError, InvalidLogLevel)
+from .json_encoder import LoggerJSONEncoder
 
 
 class Logger:
-    """
-    This is the main API class to interact with the JSON logs. Has the needed methods to log information as
+    """This is the main API class to interact with the JSON logs. Has the needed methods to log information as
     DEBUG, INFO, WARNING and ERROR levels with specific features like adding errors with tracing data,
     communicate events with with Sentry monitoring spaces and the core of this integration, stream your logs
     as Elasticsearch documents in a specific index.
@@ -34,18 +31,38 @@ class Logger:
 
     _RESERVED_KEYS = ["name", "level", "asctime", "levelname", "message", "@message", "@timestamp"]
 
-    def __init__(self, name: str, level: int = None, fmt: str = None):
-        self.extra = {}
-        self.elastic = None
-        self.sentry = None
-        self.elastic_index = None
-        self.level = level
-        self.context = Context()
-        self.logger = self._create_logger(name=name, level=level, fmt=fmt)
+    def __init__(self, name: AnyStr, level: Optional[int] = None, fmt: Optional[AnyStr] = None):
+        self._extra = {}
+        self._name = name
+        self._elastic = None
+        self._elastic_index = None
+        self._level = level
+        self._context = Context()
+        self._logger = self._create_logger(name=name, level=level, fmt=fmt)
 
-    def enable_elastic(self, url: str = None, index: str = None, **kwargs):
-        """
-        Enable ElasticSearch integration to stream logs. If you don't set endpoint and index
+    def set_level(self, level: int) -> NoReturn:
+        """Change the configured level of the logger."""
+
+        self._level = level
+        self._logger.setLevel(level)
+
+    @property
+    def level(self):
+        """Return level"""
+        return self._level
+
+    @property
+    def name(self):
+        """Get property value"""
+        return self._name
+
+    @property
+    def context(self):
+        """Return logger persistent context"""
+        return self._context
+
+    def enable_elastic(self, url: Optional[AnyStr] = None, index: Optional[AnyStr] = None, **kwargs: Any) -> NoReturn:
+        """Enable ElasticSearch integration to stream logs. If you don't set endpoint and index
         configurations this will try to get the configuration form the environment variables
         ELASTICSEARCH_URL and ELASTICSEARCH_INDEX
 
@@ -61,147 +78,74 @@ class Logger:
 
             If any Kwarg is set, default configuration will be omitted and Kwargs will be used
             in place
-        """
 
-        if len(kwargs.keys()) > 0 and "hosts" in kwargs:
-            del kwargs["hosts"]
+        :raises ESEmptyUrlError: When the url param and the ELASTICSEARCH_URL env var are empty
+        :raises ESEmptyIndexError: When the index param and the ELASTICSEARCH_INDEX env var are empty
+        :raises ESConfigurationError: When the Elasticsearch object raise a configuration error
+        """
 
         endpoint = url if url else os.getenv("ELASTICSEARCH_URL", None)
 
         if not endpoint:
             raise ESEmptyUrlError()
 
-        self.elastic_index = index if index else os.getenv("ELASTICSEARCH_INDEX", None)
+        self._elastic_index = index if index else os.getenv("ELASTICSEARCH_INDEX", None)
 
-        if not self.elastic_index:
+        if not self._elastic_index:
             raise ESEmptyIndexError("Can't find a valid ES index")
 
         try:
-            if len(kwargs.keys()) > 0:
-                if "hosts" in kwargs:
-                    del kwargs["hosts"]
-
-                self.elastic = Elasticsearch(hosts=endpoint, **kwargs)
-            else:
-                self.elastic = Elasticsearch(
-                    hosts=endpoint,
-                    use_ssl=True,
-                    verify_certs=True,
-                    ca_certs=certifi.where(),
-                    serializer=ElasticJSONEncoder()
-                )
+            self._elastic = elastic.get_instance(endpoint, **kwargs)
         except Exception as error:
             raise ESConfigurationError() from error
 
-    def enable_sentry(
-        self, url: str = None, integrations: [object] = None, level: int = DEBUG, event_level: int = ERROR
-    ):
-        """
-        Enable Sentry integration for realtime issue monitoring. If you don't set the endpoint
-        field it will be set from the env ver SENTRY_URL. On the integrations field you can set a
-        list of objects from the sentry_sdk.integrations package to be implemented.
-
-        :param url: Sentry project endpoint
-        :param integrations: List of sentry_sdk.integrations objects
-        :param level: Capture info and above as breadcrumbs
-        :param event_level: Register events when this level is use
-
-        :raise SentryEmptyUrlError: Configuration can find a provided URL or configured env var SENTRY_URL
-        """
-
-        endpoint = url if url else os.getenv("SENTRY_URL", None)
-
-        if not endpoint:
-            raise SentryEmptyUrlError()
-
-        sentry_logging = LoggingIntegration(
-            level=level,
-            event_level=event_level,
-        )
-
-        base_integrations = [sentry_logging]
-
-        if integrations is not None:
-            integrations = integrations + base_integrations
-
-        ignore_logger("root")
-        self.sentry = sentry_sdk.init(endpoint, integrations=integrations)
-
-    def fields(self, fields: dict):
-        """
-        Add multiple extra fields to the json log string
+    def fields(self, fields: Dict[AnyStr, Any]):
+        """Add multiple extra fields to the json log string
 
         :param fields: Extra fields to add in the json log
-
         :return: Self instance
         """
 
         if not isinstance(fields, dict):
             return self
 
-        self.extra.update(fields)
+        self._extra.update(fields)
         return self
 
-    def field(self, name: str, value):
-        """
-        Add a single field to the json log string
+    def field(self, name: AnyStr, value: Any):
+        """Add a single field to the json log string
 
         :param name: New key name for the field
         :param value: Value of the field (if it's an object needs to be json serializable)
-
         :return: Self instance
         """
 
-        self.extra.update({name: value})
+        self._extra.update({name: value})
         return self
 
-    def debug(self, message: str):
-        """
-        Print a debug log with all extra fields saved. The fields will be cleaned after the
+    def debug(self, message: AnyStr):
+        """Print a debug log with all extra fields saved. The fields will be cleaned after the
         logs are send
 
         :param message: Log message
         """
 
-        self.logger.debug(message, extra=self._get_extra_data())
+        self._logger.debug(message, extra=self._get_extra_data())
         self._ensure_elastic(message, DEBUG)
-        self.extra = {}
+        self._extra = {}
 
-    def debugf(self, message: str, *args, **kwargs):
-        """
-        Print a debug log with all extra fields saved and formatted message. The fields will be
-        cleaned after the logs are send
-
-        :param message: Log message
-        """
-
-        message = message.format(*args, **kwargs)
-        self.debug(message)
-
-    def info(self, message: str):
-        """
-        Print an info log with all extra fields saved. The fields will be cleaned after
+    def info(self, message: AnyStr):
+        """Print an info log with all extra fields saved. The fields will be cleaned after
         the logs are send
 
         :param message: Log message
         """
 
-        self.logger.info(message, extra=self._get_extra_data())
+        self._logger.info(message, extra=self._get_extra_data())
         self._ensure_elastic(message, INFO)
-        self.extra = {}
+        self._extra = {}
 
-    def infof(self, message: str, *args, **kwargs):
-        """
-        Print a info log with all extra fields saved and formatted message. The
-        fields will be cleaned after the logs are send
-
-        :param message: Log message
-        """
-
-        message = message.format(*args, **kwargs)
-        self.info(message)
-
-    def warning(self, message: str):
+    def warning(self, message: AnyStr):
         """
         Print a warning log with all extra fields saved. The fields will be cleaned after the
         logs are send
@@ -209,22 +153,11 @@ class Logger:
         :param message: Log message
         """
 
-        self.logger.warning(message, extra=self._get_extra_data())
+        self._logger.warning(message, extra=self._get_extra_data())
         self._ensure_elastic(message, WARNING)
-        self.extra = {}
+        self._extra = {}
 
-    def warningf(self, message: str, *args, **kwargs):
-        """
-        Print a warning log with all extra fields saved and formatted message. The fields will be
-        cleaned after the logs are send
-
-        :param message: Log message
-        """
-
-        message = message.format(*args, **kwargs)
-        self.warning(message)
-
-    def error(self, message: str, error=None):
+    def error(self, message: AnyStr, error: Any = None):
         """
         Print an error log with all extra fields saved, and with an specific error field. The
         fields will be cleaned after the logs are send
@@ -234,26 +167,13 @@ class Logger:
         """
 
         self.err(error)
-        self.logger.error(message, extra=self._get_extra_data())
+        self._logger.error(message, extra=self._get_extra_data())
         self._ensure_elastic(message, ERROR)
 
-        self.extra = {}
+        self._extra = {}
 
-    def errorf(self, error, message: str, *args, **kwargs):
-        """
-        Print an error log with all extra fields saved and formatted message, and with an specific
-        error field. The fields will be cleaned after the logs are send
-
-        :param message: Log message
-        :param error: Exception or specific error message
-        """
-
-        message = message.format(*args, **kwargs)
-        self.error(message=message, error=error)
-
-    def fatal(self, message: str, error=None):
-        """
-        Print a fatal error log with all extra fields saved, and with an specific error field. The
+    def critical(self, message: AnyStr, error: Any = None):
+        """Print a fatal error log with all extra fields saved, and with an specific error field. The
         fields will be cleaned after the logs are send
 
         :param message: Log message
@@ -261,23 +181,11 @@ class Logger:
         """
 
         self.err(error)
-        self.logger.fatal(message, extra=self._get_extra_data())
+        self._logger.fatal(message, extra=self._get_extra_data())
         self._ensure_elastic(message, FATAL)
-        self.extra = {}
+        self._extra = {}
 
-    def fatalf(self, error, message: str, *args, **kwargs):
-        """
-        Print a fatal error log with all extra fields saved, and with an specific error field. The
-        fields will be cleaned after the logs are send
-
-        :param message: Log message
-        :param error: Exception or specific error message
-        """
-
-        message = message.format(*args, **kwargs)
-        self.fatal(message=message, error=error)
-
-    def err(self, error):
+    def err(self, error: Any):
         """
         Method used to specify some error data on extra fields without logging it as an error event
 
@@ -294,18 +202,18 @@ class Logger:
         else:
             error = str(error)
 
-        self.extra["error"] = error
+        self._extra["error"] = error
 
         exc_type, exc_value, exc_tb = sys.exc_info()
         trace_length = len(traceback.format_exception(exc_type, exc_value, exc_tb))
 
         if trace_length > 1:
             trace = traceback.format_exc()
-            self.extra["trace"] = trace
+            self._extra["trace"] = trace
 
         return self
 
-    def _ensure_elastic(self, message: str, level: int):
+    def _ensure_elastic(self, message: AnyStr, level: int):
         """
         Ensure elastic search synchronization, by checking configuration and collecting data
 
@@ -313,7 +221,7 @@ class Logger:
         :param level: ES document level for the log
         """
 
-        if not self.elastic or not self._check_level(level):
+        if not self._elastic or not self._check_level(level):
             return
 
         extra_fields = self._get_extra_data()
@@ -322,7 +230,7 @@ class Logger:
             "@timestamp": datetime.now(),
             "@message": message,
             "level": self._get_level_name(level),
-            "name": self.logger.name,
+            "name": self._logger.name,
         }
 
         document.update(extra_fields)
@@ -332,7 +240,7 @@ class Logger:
 
         document = self._clean_metadata_keys(document)
 
-        self.elastic.index(index=self.elastic_index, body=document)
+        self._elastic.index(index=self._elastic_index, body=document)
 
     def _get_extra_data(self):
         """
@@ -341,13 +249,13 @@ class Logger:
         :return: Dict with all log data
         """
 
-        with self.context as context:
-            data = self.extra
+        with self._context as context:
+            data = self._extra
             data.update(context.data)
 
             return self._clean_reserved_keys(data)
 
-    def _clean_reserved_keys(self, extra_data: dict):
+    def _clean_reserved_keys(self, extra_data: Dict[AnyStr, Any]):
         """
         Delete logger reserved keys to avoid override data
 
@@ -370,19 +278,19 @@ class Logger:
         :return: Boolean assertion
         """
 
-        if level == logging.DEBUG and self.level == DEBUG:
+        if level == logging.DEBUG and self._level == DEBUG:
             return True
 
-        if level == logging.INFO and self.level in {DEBUG, INFO}:
+        if level == logging.INFO and self._level in {DEBUG, INFO}:
             return True
 
-        if level == logging.WARNING and self.level in {DEBUG, INFO, WARNING}:
+        if level == logging.WARNING and self._level in {DEBUG, INFO, WARNING}:
             return True
 
-        if level == logging.ERROR and self.level in {DEBUG, INFO, WARNING, ERROR}:
+        if level == logging.ERROR and self._level in {DEBUG, INFO, WARNING, ERROR}:
             return True
 
-        if level == logging.FATAL and self.level in {DEBUG, INFO, WARNING, ERROR, FATAL}:
+        if level == logging.FATAL and self._level in {DEBUG, INFO, WARNING, ERROR, FATAL}:
             return True
 
         return False
@@ -413,7 +321,7 @@ class Logger:
         raise InvalidLogLevel("Invalid logging level detected: [%d]" % level)
 
     @staticmethod
-    def _create_logger(name: str, level: int = None, fmt: str = None):
+    def _create_logger(name: AnyStr, level: int = None, fmt: AnyStr = None) -> logging.Logger:
         """
         Configure python JSON logger
 
@@ -437,7 +345,7 @@ class Logger:
         return logger
 
     @staticmethod
-    def _clean_metadata_keys(document: dict):
+    def _clean_metadata_keys(document: Dict[AnyStr, Any]):
         """
         Remove all keys of a document that start with underscore to not be confused with metadata keys
         :param document: Full document data
